CupertinoAppData class

Platform-specific configuration for CupertinoApp

Constructors

CupertinoAppData({Color? color, bool showPerformanceOverlay = false, bool checkerboardRasterCacheImages = false, bool checkerboardOffscreenLayers = false, bool showSemanticsDebugger = false, bool debugShowCheckedModeBanner = false, Map<ShortcutActivator, Intent>? shortcuts, Map<Type, Action<Intent>>? actions, String? restorationScopeId, ScrollBehavior? scrollBehavior})
const

Properties

actions Map<Type, Action<Intent>>?
final
checkerboardOffscreenLayers bool
final
checkerboardRasterCacheImages bool
final
color Color?
final
debugShowCheckedModeBanner bool
final
hashCode int
The hash code for this object.
no setterinherited
restorationScopeId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollBehavior ScrollBehavior?
final
shortcuts Map<ShortcutActivator, Intent>?
final
showPerformanceOverlay bool
final
showSemanticsDebugger bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited