IOS26AlertDialog class

Native iOS 26 alert dialog implementation using platform views

Inheritance

Constructors

IOS26AlertDialog({Key? key, required String title, String? message, required List<AlertAction> actions, String? icon, double? iconSize, Color? iconColor, String? oneTimeCode, AdaptiveAlertDialogInput? input})
Creates an iOS 26 alert dialog
const

Properties

actions List<AlertAction>
List of actions for the alert
final
hashCode int
The hash code for this object.
no setterinherited
icon String?
Optional SF Symbol icon name to display in the alert
final
iconColor Color?
Optional icon color
final
iconSize double?
Optional icon size
final
input AdaptiveAlertDialogInput?
Optional text input configuration
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
message String?
Optional message text for additional context
final
oneTimeCode String?
Optional 6-digit one-time code to display
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
The title of the alert dialog
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<IOS26AlertDialog>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited